@@ -20,9 +20,10 @@
 
 import asyncio
 import functools
+import typing
 
 
-def awaitable(func):
+def awaitable(func: typing.Callable):
     """
     Decorates a synchronous function to run it in asynchronous
     :param func: function to decorate
@@ -35,3 +36,10 @@ def awaitable(func):
         pfunc = functools.partial(func, *args, **kwargs)
         return await loop.run_in_executor(executor, pfunc)
     return run
+
+
+def run_awaitable(func: typing.Callable, *args, **kwargs) -> None:
+    """
+    Execute an awaitable function with arguments
+    """
+    return asyncio.run(func(*args, **kwargs))
